Date: 2015-08-04

# Constant Field Values

## Contents

- jep.*

## jep.*

- jep.Util
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final int` | `JARRAY_ID` | `9`
  `public static final int` | `JBOOLEAN_ID` | `0`
  `public static final int` | `JBYTE_ID` | `11`
  `public static final int` | `JCHAR_ID` | `10`
  `public static final int` | `JCLASS_ID` | `12`
  `public static final int` | `JDOUBLE_ID` | `6`
  `public static final int` | `JFLOAT_ID` | `8`
  `public static final int` | `JINT_ID` | `1`
  `public static final int` | `JLONG_ID` | `2`
  `public static final int` | `JOBJECT_ID` | `3`
  `public static final int` | `JSHORT_ID` | `7`
  `public static final int` | `JSTRING_ID` | `4`
  `public static final int` | `JVOID_ID` | `5`